Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/bno055_simpletest.py
    :caption: examples/bno055_simpletest.py
    :linenos:


Raspberry PI I2C GPIO Simpletest
--------------------------------

This example demonstrates how to instantiate the
Adafruit BNO055 Sensor using this library and just
the I2C bus number.

.. literalinclude:: ../examples/bno055_i2c-gpio_simpletest.py
    :caption: examples/bno055_i2c-gpio_simpletest.py
    :linenos:
